@@ -3,9 +3,10 @@ from sys import exit, stderr
 from pathlib import Path
 from os import environ
 
-from .base import dumb_pipe, using_path, play_while_running, \
-  is_pipeline, RC_ENV_VAR, DEFAULT_SOUND, RC_OK
+from .base import dumb_pipe, using_path, is_pipeline, \
+  RC_ENV_VAR, RC_OK
 
+from play_sounds import play_while_running
 import click
 
 
@@ -15,9 +16,9 @@ ENV_VAR = 'ONHOLD'
 def run(file: Optional[Path] = None):
   if not file:
     dumb_pipe()
-    return 
+    return
 
-  with play_while_running(file) as proc:
+  with play_while_running(file):
     dumb_pipe()
 
 
